@@ -1,5 +1,11 @@
+from abc import abstractmethod
 from pathlib import Path
-from typing import Optional, Sequence
+from typing import TYPE_CHECKING, Optional, Sequence
+
+from .write_html import HTMLTable
+
+if TYPE_CHECKING:
+    from .chunks import Chunk
 
 
 class ExtensionPoint:
@@ -22,9 +28,7 @@ class Extension:
     def files_to_string(self, files: Sequence[Path]) -> str:
         string: str = ""
         for file in files:
-            with open(
-                file, "r", encoding="utf-8", errors="surrogateescape"
-            ) as open_file:
+            with open(file, encoding="utf-8", errors="surrogateescape") as open_file:
                 string += open_file.read()
         return string
 
@@ -35,7 +39,7 @@ class Extension:
         return self.files_to_string(self._find_files("*.js"))
 
     def get_examples(self):
-        return self._find_files("examples/*.md")
+        return self._find_files("example-*.md")
 
     def get_doc(self) -> Optional[Path]:
         files = self._find_files("doc.md")
@@ -45,3 +49,12 @@ class Extension:
 
     def __str__(self) -> str:
         return "Extension at " + str(self.folder)
+
+    def get_spec_html(self) -> str:
+        return ""
+
+    @abstractmethod
+    def get_doc_table(
+        self, example_chunks: Optional[Sequence["Chunk"]] = None
+    ) -> HTMLTable:
+        ...
