@@ -1,3 +1,4 @@
+from pathlib import Path
 from typing import Any, Dict, List
 
 from pygments import highlight
@@ -20,7 +21,18 @@ class Code(Chunk):
     def get_chunk_type(self) -> str:
         return "code" if self.lang is None else f"code/{self.lang}"
 
-    def to_html(self, builder: Builder) -> str:
+    def to_html(self, builder: Builder, target_file_path: Path) -> str:
+        # lexer = None
+        # if self.lang is not None:
+        #     try:
+        #         lexer = get_lexer_by_name(self.lang, stripall=True)
+        #     except Exception as e:
+        #         print(e)
+        # output: List[str] = []
+        # if lexer is not None:
+        #     formatter = HtmlFormatter()
+        #     output.append(highlight(self.code, lexer, formatter))
+        #     return "\n".join(output)
         return builder.convert_code(self.get_content(), target_format="html")
 
     def to_latex(self, builder: Builder) -> str:
