@@ -1,5 +1,7 @@
+from pathlib import Path
 from typing import Any, Dict, Sequence
-from ... import YamlExtension, YAMLChunk, RawChunk, Builder
+
+from ... import Builder, RawChunk, YAMLChunk, YamlExtension
 
 
 class ButtonExtension(YamlExtension):
@@ -18,7 +20,7 @@ class Button(YAMLChunk):
             raw_chunk, dictionary, page_variables, required=["url", "text"]
         )
 
-    def to_html(self, builder: Builder):
+    def to_html(self, builder: Builder, target_file_path: Path):
         clazz = "ntnu-button"
         html: Sequence[str] = []
         html.append(
