@@ -1,5 +1,7 @@
-from ... import YAMLChunk, YamlExtension, Builder, RawChunk
-from typing import Dict, Any, List
+from pathlib import Path
+from typing import Any, Dict, List
+
+from ... import Builder, RawChunk, YAMLChunk, YamlExtension
 
 
 class LinesExtension(YamlExtension):
@@ -18,7 +20,7 @@ class Lines(YAMLChunk):
         # print("--------     init lines extension")
         super().__init__(raw_chunk, dictionary, page_variables, required=["lines"])
 
-    def to_html(self, builder: Builder):
+    def to_html(self, builder: Builder, target_file_path: Path):
         html: List[str] = []
         for _ in range(self.dictionary["lines"]):
             html.append('<hr class="lines"/>')
