@@ -1,7 +1,7 @@
-import os
-from typing import Any, Dict, Optional, Sequence
+from pathlib import Path
+from typing import Any, Dict, Sequence
 
-from ... import YAMLChunk, YamlExtension, RawChunk, Builder
+from ... import Builder, RawChunk, YAMLChunk, YamlExtension
 
 
 class QuoteExtension(YamlExtension):
@@ -24,7 +24,7 @@ class Quote(YAMLChunk):
             optional=["link", "title"],
         )
 
-    def to_html(self, builder: Builder):
+    def to_html(self, builder: Builder, target_file_path: Path):
         html: Sequence[str] = []
 
         link = self.dictionary["link"] if "link" in self.dictionary else None
