@@ -1,12 +1,11 @@
-import os
-import re
-from ...extend import TableClassExtension, Extension
+from pathlib import Path
 from typing import Any, Dict, List, Optional, Sequence, Set
 
 import wikitextparser as wtp
 from wikitextparser._table import Cell
 
-from ... import Chunk, YAMLChunk, YamlExtension, RawChunk, Builder
+from ... import Builder, Chunk, RawChunk, YAMLChunk, YamlExtension
+from ...extend import Extension, TableClassExtension
 
 
 class TableExtension(YamlExtension):
@@ -46,14 +45,17 @@ class Table(YAMLChunk):
         if self.has_post_yaml():
             self.table_raw = self.get_post_yaml()
         elif "file" in dictionary:
-            file_path = os.path.join(
-                os.path.dirname(os.path.dirname(raw_chunk.path)), dictionary["file"]
-            )
-            if not os.path.exists(file_path):
-                self.error("Table file {} does not exist.".format(file_path))
+            file_path = (raw_chunk.path.parent / dictionary["file"]).resolve()
+            if not file_path.exists():
+                # TODO this is the old way, should now be relative to chunk as above
+                file_path = (
+                    raw_chunk.path.parent.parent / dictionary["file"]
+                ).resolve()
+            if not file_path.exists():
+                self.error(f"Table file {file_path} does not exist.")
                 self.ok = False
             else:
-                with open(file_path, "r") as myfile:
+                with open(file_path) as myfile:
                     self.table_raw = myfile.read()
         else:
             self.error("Table must either refer to a file or have a post-yaml section.")
@@ -105,7 +107,7 @@ class Table(YAMLChunk):
         parsed = wtp.parse(self.table_raw)
         rows = parsed.tables[0].cells(span=False)
         if self.div_class:
-            output.append('<table class="{} table table-sm">'.format(self.div_class))
+            output.append(f'<table class="{self.div_class} table table-sm">')
         else:
             output.append('<table class="table table-sm">')
         for row in rows:
@@ -139,7 +141,7 @@ class Table(YAMLChunk):
         output.append("</table>")
         return "\n".join(output)
 
-    def to_html(self, builder: Builder) -> str:
+    def to_html(self, builder: Builder, target_file_path: Path) -> str:
         empty_cell = (
             ""
             if self.table_extension is None
@@ -152,19 +154,20 @@ class Table(YAMLChunk):
         else:
             source_format = "md"
         output = self._cellwise_to_html(source_format, empty_cell, builder)
-        html.append(output)
+        # html.append(output)
         if "caption" in self.dictionary:
             if "file" in self.dictionary:
                 table_id = self.dictionary["file"]
             else:
                 table_id = Chunk.create_hash(self.table_raw)
-            html.append('<span name="{}">&nbsp;</span>'.format(table_id))
+            html.append(f'<span name="{table_id}">&nbsp;</span>')
             html.append(
                 '<aside name="{}"><p>{}</p></aside>'.format(
                     table_id,
                     builder.convert(self.dictionary["caption"], target_format="html"),
                 )
             )
+        html.append(output)
         return "\n".join(html)
 
     def get_scss(self):
@@ -183,7 +186,7 @@ class Table(YAMLChunk):
             rowspec = rowspec + "L"
         latex: Sequence[str] = []
         latex.append("\\begin{table*}[t]")
-        latex.append("\\begin{tabulary}{\\textwidth}" + "{{{}}}".format(rowspec))
+        latex.append("\\begin{tabulary}{\\textwidth}" + f"{{{rowspec}}}")
         latex.append("\\toprule")
 
         source_format = (
